Index: addimage.c
===================================================================
--- addimage.c	(revision 102)
+++ addimage.c	(working copy)
@@ -22,19 +22,19 @@
 {
 	SLL* list;
 	char *cat_name, *image_name, *image_path, *quick_desc, *long_desc;
-	const char *type, *author, *year;
+	const char *type, *author, *year, *language;
 	char sql_command [1024];
 	char *dbErrMsg = NULL;
         sqlite3* db;
 	int got, id = -1;
 	FILE* f;
 	const char* questions[] = { "Image Name: ", "Category name: ", "Type (CD/DVD) [CD]: ", "Year: ", 
-				    "Author: ", "Absolute path of ISO file: ",
-				    "Quick description: ", "Long Description: ", "", "", "", "", "", "r", "", " " };
+				    "Author: ", "Language: ", "Absolute path of ISO file: ",
+				    "Quick description: ", "Long Description: ", "", "", "", "", "", "", "r", "", " " };
 	if(!path || !args) return 0;
 
 	/* order: category, name, type, year, author, isopath, desc, longdesc */
-	list = userinput(questions, 8, args);
+	list = userinput(questions, 9, args);
 
 	if(!list)
 		return 0;
@@ -127,8 +127,20 @@
 	if(!strcmp(author, ""))
 		author = "Unbekannt";
 
-	image_path = getSLL(list, 5, &got);
+	language = getSLL(list, 5, &got);
 
+	if(!got)
+	{
+		fprintf(stderr, "Unexpected error\n");
+		cleanupSLL(list);
+		return 0;
+	}
+
+	if(!strcmp(language, ""))
+		language = "Unbekannt";	
+
+	image_path = getSLL(list, 6, &got);
+
         if(!got)
         {
                 fprintf(stderr, "Unexpected error\n");
@@ -154,7 +166,7 @@
 
 	fclose(f);
 
-	quick_desc = getSLL(list, 6, &got);
+	quick_desc = getSLL(list, 7, &got);
 
 	if(!got)
         {
@@ -170,7 +182,7 @@
 		return 0;
 	}
 
-	long_desc = getSLL(list, 7, &got);
+	long_desc = getSLL(list, 8, &got);
 
         if(!got)
         {
@@ -210,9 +222,9 @@
 
 	/* order: category, name, type, year, author, isopath, desc, longdesc */
 
-	sprintf(sql_command, "INSERT INTO image(cat, name, desc, longdesc, type, year, author, path) "
-			"VALUES('%d', '%s', '%s', '%s', '%s', '%s', '%s', '%s')", id, image_name,
-			quick_desc, long_desc, type, year, author, image_path);
+	sprintf(sql_command, "INSERT INTO image(cat, name, desc, longdesc, type, year, author, path, language) "
+			"VALUES('%d', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s')", id, image_name,
+			quick_desc, long_desc, type, year, author, image_path, language);
 
 	got = sqlite3_exec(db, sql_command, NULL, NULL, &dbErrMsg);
 
Index: install.c
===================================================================
--- install.c	(revision 102)
+++ install.c	(working copy)
@@ -61,6 +61,7 @@
   name TEXT NOT NULL,\n\
   desc TEXT NOT NULL,\n\
   longdesc TEXT NOT NULL,\n\
+  language TEXT NOT NULL,\n\
   type TEXT NOT NULL DEFAULT 'CD',\n\
   year TEXT NOT NULL,\n\
   author TEXT NOT NULL,\n\
Index: showimage.c
===================================================================
--- showimage.c	(revision 102)
+++ showimage.c	(working copy)
@@ -20,17 +20,18 @@
 
 static int showimg(void *NotUsed, int argc, char **argv, char **azColName)
 {
 	/* SELECT name,desc,longdesc,type,year,author,path,cat FROM image WHERE cat = %d 
 	 *        0    1    2        3    4    5      6    7
 	 */
 
-	printf("--------------\n- %s(%s) [%s]\nCategory: %s\nAuthor: %s\nYear: %s\nPath: %s\nDescription: %s\n--------------\n\n", 
+	printf("--------------\n- %s(%s) [%s]\nCategory: %s\nAuthor: %s\nYear: %s\nLanguage: %s\nPath: %s\nDescription: %s\n--------------\n\n", 
 			argv[0],
 			argv[1],
 			argv[3],
 			argv[7],
 			argv[5],
 			argv[4],
+			argv[8],
 			argv[6],
 			argv[2]);
 	
@@ -93,9 +94,9 @@
 			return 0;
 		}
 
-		sprintf(sql_command, "SELECT I.name,I.desc,I.longdesc,I.type,I.year,I.author,I.path,C.name FROM image I JOIN category C ON I.cat = C.id WHERE I.cat = %d ORDER BY I.name", catid);
+		sprintf(sql_command, "SELECT I.name,I.desc,I.longdesc,I.type,I.year,I.author,I.path,C.name,I.language FROM image I JOIN category C ON I.cat = C.id WHERE I.cat = %d ORDER BY I.name", catid);
 	} else
-		sprintf(sql_command, "SELECT I.name,I.desc,I.longdesc,I.type,I.year,I.author,I.path,C.name FROM image I JOIN category C ON I.cat = C.id ORDER BY I.name");
+		sprintf(sql_command, "SELECT I.name,I.desc,I.longdesc,I.type,I.year,I.author,I.path,C.name,I.language FROM image I JOIN category C ON I.cat = C.id ORDER BY I.name");
 
 	got = sqlite3_exec(db, sql_command, showimg, NULL, &dbErrMsg);
 
@@ -20,17 +20,18 @@
 static int showimg(void *NotUsed, int argc, char **argv, char **azColName)
 {
-	/* SELECT name,desc,longdesc,type,year,author,path,cat FROM image WHERE cat = %d 
-	 *        0    1    2        3    4    5      6    7
+	/* SELECT name,desc,longdesc,type,year,author,path,cat,language FROM image WHERE cat = %d 
+	 *        0    1    2        3    4    5      6    7   8
 	 */
 
